@@ -429,7 +429,8 @@ impl Shadow {
         let desc = format!(
             r#"// Code automatically generated by `shadow-rs` (https://github.com/baoyachi/shadow-rs), do not edit.
 // Author: https://www.github.com/baoyachi
-// Generation time: {}"#,
+// Generation time: {}
+"#,
             DateTime::now().human_format()
         );
         writeln!(&self.f, "{desc}\n\n")?;
@@ -442,6 +443,7 @@ impl Shadow {
         let define = match val.t {
             ConstType::OptStr => format!(
                 "#[allow(dead_code)]\n\
+                #[allow(clippy::all)]\n\
             pub const {} :{} = r#\"{}\"#;",
                 shadow_const.to_ascii_uppercase(),
                 ConstType::Str.to_string(),
@@ -449,6 +451,7 @@ impl Shadow {
             ),
             ConstType::Str => format!(
                 "#[allow(dead_code)]\n\
+                #[allow(clippy::all)]\n\
             pub const {} :{} = r#\"{}\"#;",
                 shadow_const.to_ascii_uppercase(),
                 ConstType::Str.to_string(),
